from sunpal.model import Model
from sunpal import request


class Consulta(Model):
    fields = [
        "id",
        "folio",
        "reference",
        "user",
    ]

    @staticmethod
    def create(params=None, env=None, headers=None):
        return request.send(
            "post", request.uri_path("burocredito/record"), params, env, headers
        )

    @staticmethod
    def retrieve(id, params, env=None, headers=None):
        return request.send(
            "get", request.uri_path("burocredito/record", id), params, env, headers
        )



from sunpal.api_error import APIError, InvalidRequestError, OperationFailedError
from sunpal.models import *
from sunpal.main import SunPal


def configure(api_key, site):
    SunPal.configure(
        {
            "api_key": api_key,
            "site": site,
        }
    )


def update_connect_timeout_secs(connect_timeout):
    SunPal.update_connect_timeout_secs(connect_timeout)


def update_read_timeout_secs(read_timeout):
    SunPal.update_read_timeout_secs(read_timeout)



import os
import sunpal
import unittest

api_key = os.environ.get("API_KEY_SUNPAL")
site = "sunwise"
sunpal.configure(api_key, site)


class SendNipTestCase(unittest.TestCase):
    def test_send_new_nip(self):
        entry = sunpal.Customer.send_nip({"rfc": "EAEN6506051Y8"})
        self.assertTrue(entry.customer, True)


if __name__ == "__main__":
    unittest.main()



import os.path

from sunpal.environment import Environment


class SunPal(object):

    default_env = None

    verify_ca_certs = False
    ca_cert_path = os.path.join(os.path.dirname(__file__), "ssl", "ca-certs.crt")

    @classmethod
    def configure(cls, options):
        cls.default_env = Environment(options)

    @classmethod
    def update_connect_timeout_secs(cls, connect_timeout):
        cls.default_env.connect_timeout = connect_timeout

    @classmethod
    def update_read_timeout_secs(cls, read_timeout):
        cls.default_env.read_timeout = read_timeout



import os


class Environment(object):

    sunpal_domain = "api.sunpal.io"
    protocol = "https"
    if "LOCAL_SUNPAL_DOMAIN" in os.environ:
        sunpal_domain = os.environ.get("LOCAL_SUNPAL_DOMAIN")
        protocol = "http"

    API_VERSION = "v1"
    connect_timeout = 30
    read_timeout = 80

    def __init__(self, options):
        self.api_key = options["api_key"]
        self.site = options["site"]

        if self.sunpal_domain is None:
            self.api_endpoint = "https://%s/api/%s" % (
                # self.site,
                self.sunpal_domain,
                self.API_VERSION,
            )
        else:
            self.api_endpoint = "http://%s/api/%s" % (
                # self.site,
                self.sunpal_domain,
                self.API_VERSION,
            )

    def api_url(self, url):
        # print(self.api_endpoint + url)
        return self.api_endpoint + url



class APIError(Exception):
    def __init__(self, http_code, json_obj):
        Exception.__init__(self, json_obj.get("errors"))
        self.json_obj = json_obj
        self.http_status_code = http_code
        # self.type = json_obj.get("type")
        # self.api_error_code = json_obj.get("api_error_code")
        # self.param = json_obj.get("param")

        # self.error_code = json_obj["error_code"]
        self.http_code = http_code
        self.http_body = None


class InvalidRequestError(APIError):
    def __init__(self, http_code, json_obj):
        APIError.__init__(self, http_code, json_obj)


class OperationFailedError(APIError):
    def __init__(self, http_code, json_obj):
        APIError.__init__(self, http_code, json_obj)



import sys

try:
    import simplejson as json  # noqua
except ImportError:
    import json  # noqua

py_major_v = sys.version_info[0]
py_minor_v = sys.version_info[1]

if py_major_v < 3:
    from urllib import urlencode  # noqua
    from urlparse import urlparse  # noqua
elif py_major_v >= 3:
    from urllib.parse import urlencode, urlparse  # noqua



from sunpal.compat import json
from sunpal.models import Customer, Consulta, Interactive


class Result(object):
    def __init__(self, response):
        self._response = response
        self._response_obj = {}

    @property
    def holograph(self):
        return self._get("holograph", Interactive.Signature, {})

    @property
    def documment(self):
        return self._get("documment", Interactive.Documment, {})

    @property
    def datasheet(self):
        return self._get("datasheets", Interactive.DataSheet, {})

    @property
    def datasheets(self):
        return self._get_list("datasheets", Interactive.DataSheet, [])

    @property
    def interactive(self):
        return self._get("interactive", Interactive, {})

    @property
    def consulta(self):
        return self._get("consulta", Consulta, {})

    @property
    def address(self):
        return self._get("address", Customer, {})

    @property
    def customer(self):
        return self._get(
            "customer",
            Customer,
            {"status": Customer.StatusItem, "records": Customer.RecordItem},
        )

    def _get_list(
        self, type, cls, sub_types={}, dependant_types={}, dependant_sub_types={}
    ):
        if not type in self._response:
            return None

        set_val = []
        for obj in self._response[type]:
            if isinstance(obj, dict):
                model = cls.construct(obj, sub_types, dependant_types)
                for k in dependant_sub_types:
                    model.init_dependant(obj, k, dependant_sub_types[k])
                set_val.append(model)

        self._response_obj[type] = set_val
        return self._response_obj[type]

    def _get(self, type, cls, sub_types=None, dependant_types=None):
        if self._response == {}:
            return None
        return cls.construct(self._response, sub_types, dependant_types)

        # Mapeo por objetos en el resultado
        # if not type in self._response:
        #     return None

        # if not type in self._response_obj:
        #     self._response_obj[type] = cls.construct(
        #         self._response[type], sub_types, dependant_types
        #     )
        # return self._response_obj[type]

    def __str__(self):
        return json.dumps(self._response, indent=4)


class Content(Result):
    pass



from sunpal import compat
from collections import OrderedDict


def serialize(value, prefix=None, idx=None):

    serialized = OrderedDict()

    if isinstance(value, dict):
        for k, v in list(value.items()):
            if isinstance(v, (dict, list, tuple)):
                serialized.update(serialize(v, k))
            else:
                key = "".join(
                    [
                        prefix or "",
                        "[%s]" % k if prefix is not None else k,
                        "[%s]" % idx if idx is not None else "",
                    ]
                )
                serialized.update({key: get_val(v)})

    elif isinstance(value, (list, tuple)):
        for i, v in enumerate(value):
            serialized.update(serialize(v, prefix, i))

    else:
        if prefix is not None and idx is not None:
            key = prefix + "[" + str(idx) + "]"
            serialized.update({key: get_val(value)})
        else:
            raise TypeError("only hash or arrays are allowed as value")

    return serialized


def get_val(val):
    if val is None:
        return ""
    elif isinstance(val, bool):
        return str(val).lower()
    else:
        if compat.py_major_v < 3 and isinstance(val, unicode):
            return val.encode("utf-8")
        else:
            return val



import os
import sunpal
import unittest

api_key = os.environ.get("API_KEY_SUNPAL")
site = "sunwise"
sunpal.configure(api_key, site)


class ConsultaTestCase(unittest.TestCase):
    def test_generate_consulta(self):
        entry = sunpal.Consulta.create(
            {
                "reference": "proposal-uuid-sunwise",
                "rfc": "EAEN6506051Y8",
                "first_name": "NOVENTAYTRES",
                "second_name": "PRUEBA",
                "first_last_name": "EXPPAT",
                "second_last_name": "EXPMAT",
            }
        )

        self.assertTrue(entry.consulta, True)

    def test_get_buro_status(self):
        entry = sunpal.Consulta.retrieve(
            id="EAEN6506051Y8",
            params={"reference": "proposal-uuid-sunwise"},
        )
        self.assertTrue(entry.consulta, True)


if __name__ == "__main__":
    unittest.main()



import os
import sunpal
import unittest

api_key = os.environ.get("API_KEY_SUNPAL")
site = "sunwise"
sunpal.configure(api_key, site)


class TestCases(unittest.TestCase):
    def test_retrieve(self):
        entry = sunpal.Interactive.retrieve("238754ef-fc8d-469c-859d-caa029e3cb23")
        # print()
        # print(entry.interactive)
        self.assertTrue(hasattr(entry.interactive, "id"), True)

    def test_create(self):
        entry = sunpal.Interactive.create(
            {
                "proposal_ref_id": "238754ef-fc8d-469c-859d-caa029e3cb23",
                "proposal_creation_date": "2022-07-29",
                "client_full_name": "Abner Grajales",
                "project_name": "Project Name",
                "company_ref_id": "d7d161bc-b398-47e9-a5df-102bf3cc9e39",
                "company_name": "Company Name",
                "compay_logo_url": "https://static.intercomassets.com/avatars/3486213/square_128/custom_avatar-1611956778.png",
            }
        )

        self.assertTrue(hasattr(entry.interactive, "id"), True)

    def test_delete(self):
        sunpal.Interactive.delete("238754ef-fc8d-469c-859d-caa029e3cb23")
        self.assertTrue(True, True)

    def test_update(self):

        entry = sunpal.Interactive.update(
            "238754ef-fc8d-469c-859d-caa029e3cb23",
            {
                "client_full_name": "Nombre del Contacto",
                "has_permalink": True,
                "project_name": "Project Name",
                "company_name": "Company Name",
                "compay_logo_url": "https://static.intercomassets.com/avatars/3486213/square_128/custom_avatar-1611956778.png",
            },
        )

        self.assertTrue(hasattr(entry.interactive, "id"), True)

    def test_upload_content_file(self):

        entry = sunpal.Interactive.update(
            "238754ef-fc8d-469c-859d-caa029e3cb23",
            {
                "client_full_name": "Annnnerrere",
            },
            file={"content_file": open("/tmp/example.json", "rb")},
        )

        self.assertTrue(hasattr(entry.interactive, "id"), True)

    def test_retrieve_signature(self):
        entry = sunpal.Interactive.retrieve_signature(
            "238754ef-fc8d-469c-859d-caa029e3cb23"
        )
        print("entry.holograph", entry.holograph.signature)
        self.assertTrue(True, True)

    def test_retrieve_datasheets(self):
        entry = sunpal.Interactive.retrieve_datasheets(
            params={"proposal_ref_id": "238754ef-fc8d-469c-859d-caa029e3cb23"}
        )
        print("entry.datasheets", entry)
        self.assertTrue(True, True)

    def test_add_datasheet(self):
        entry = sunpal.Interactive.add_datasheet(
            {
                "proposal_ref_id": "d0abe2c9-e65a-4a4a-aa11-26f7023c0ab8",
                "type": "panels",
                "name": "AE350M6_72",
            },
            file={"archive": open("/tmp/example.txt", "rb")},
        )

        print("entry.datasheet", entry.datasheet)
        self.assertTrue(True, True)

    def test_delete_datasheet(self):
        sunpal.Interactive.delete_datasheet(
            id="ed684016-4aa1-4d7f-9d88-42911fee268e",
            params={"proposal_ref_id": "238754ef-fc8d-469c-859d-caa029e3cb23"},
        )
        self.assertTrue(True, True)

    def test_retrieve_documments(self):
        entry = sunpal.Interactive.retrieve_documments(
            params={"proposal_ref_id": "238754ef-fc8d-469c-859d-caa029e3cb23"}
        )
        print("entry.documments", entry)
        self.assertTrue(True, True)

    def test_add_documments(self):
        entry = sunpal.Interactive.add_documment(
            {
                "proposal_ref_id": "238754ef-fc8d-469c-859d-caa029e3cb23",
                "document_reference_id": "987754ef-fc8d-469c-859d-caa029e3ex55",
                "name": "Smart Documment Demo",
            }
        )

        print("entry.documment", entry.documment)
        self.assertTrue(True, True)

    def test_delete_documment(self):
        sunpal.Interactive.delete_documment(
            id="86e30d54-9966-489d-92af-79a53b9db1ee",
            params={"proposal_ref_id": "238754ef-fc8d-469c-859d-caa029e3cb23"},
        )
        self.assertTrue(True, True)

    def test_delete_documment_by_reference(self):
        sunpal.Interactive.delete_documment_by_reference(
            "75bd6d83-73a7-4b26-9389-eafcb65f5a9f"
        )
        self.assertTrue(True, True)

    def test_remove_approbal(self):
        sunpal.Interactive.remove_approbal("238754ef-fc8d-469c-859d-caa029e3cb23")
        self.assertTrue(True, True)

    def test_revoke_signature(self):
        sunpal.Interactive.revoke_signature("238754ef-fc8d-469c-859d-caa029e3cb23")
        self.assertTrue(True, True)

    # def test_upload_proposal_content(self):
    #     entry = sunpal.Interactive.upload_proposal_content(
    #         "d0abe2c9-e65a-4a4a-aa11-26f7023c0ab8",
    #         file={"content": open("/tmp/example.json", "rb")},
    #     )

    #     print("entry.datasheet", entry.datasheet)
    #     self.assertTrue(True, True)


if __name__ == "__main__":
    unittest.main()



import base64
import logging
import platform
import requests

from sunpal import APIError, InvalidRequestError, OperationFailedError, compat
from sunpal.main import SunPal
from sunpal.main import Environment
from sunpal import compat
from sunpal.version import VERSION

_logger = logging.getLogger(__name__)


def _basic_auth_str(username):
    return "Basic " + base64.b64encode(
        ("%s:" % username).encode("latin1")
    ).strip().decode("latin1")


def request(method, url, env, params=None, headers=None, file=None):
    if not env:
        raise Exception("No environment configured.")
    if headers is None:
        headers = {}

    url = env.api_url(url)
    if method.lower() in ("get", "head", "delete"):
        if params:
            url = "%s?%s" % (url, compat.urlencode(params))

        payload = None
    else:
        payload = compat.urlencode(params)
        headers["Content-type"] = "application/x-www-form-urlencoded"

    headers.update(
        {
            "User-Agent": "Sunpal-Python-Client v%s" % VERSION,
            "Accept": "application/json",
            "api-key": env.api_key,
            "Lang-Version": str(compat.py_major_v) + "." + str(compat.py_minor_v),
            "OS-Version": platform.platform(),
        }
    )

    meta = compat.urlparse(url)
    request_args = {
        "method": method.upper(),
        "timeout": (env.connect_timeout, env.read_timeout),
        "data": payload,
        "headers": headers,
    }

    if file:
        request_args.update({"files": file})
        headers.pop("Content-type")
        headers.pop("Accept")
        request_args["data"] = params

    uri = meta.netloc + meta.path + "?" + meta.query

    if SunPal.verify_ca_certs:
        request_args.update(
            {
                "verify": SunPal.ca_cert_path,
                "url": "https://" + uri,
            }
        )
    else:
        if Environment.protocol == "https":
            request_args.update(
                {
                    "url": "https://" + uri,
                }
            )
        else:
            request_args.update(
                {
                    "url": "http://" + uri,
                }
            )

    _logger.debug("{method} Request: {url}".format(**request_args))
    _logger.debug(
        "HEADERS: {0}".format(
            {k: v for k, v in headers.items() if k.lower() != "authorization"}
        )
    )
    if payload:
        _logger.debug("PAYLOAD: {data}".format(**request_args))

    response = requests.request(**request_args)

    if compat.py_major_v >= 3:
        _logger.debug(
            "{method} Response: {status_code} - {text}".format(
                method=request_args["method"],
                status_code=response.status_code,
                text=response.text,
            )
        )
    elif compat.py_major_v < 3:
        _logger.debug(
            "{method} Response: {status_code} - {text}".format(
                method=request_args["method"],
                status_code=response.status_code,
                text=response.text.encode("utf 8"),
            )
        )

    return process_response(url, response.text, response.status_code)


def process_response(url, response, http_code):
    try:
        if response:
            resp_json = compat.json.loads(response)
        else:
            resp_json = {}

    except Exception:
        if "503" in response:
            raise Exception(
                "Sorry, the server is currently unable to handle the request due to a temporary overload or scheduled maintenance. Please retry after sometime. \n type: internal_temporary_error, \n http_status_code: 503, \n error_code: internal_temporary_error,\n content:"
                + response
            )
        elif "504" in response:
            raise Exception(
                "The server did not receive a timely response from an upstream server, request aborted. If this problem persists, contact us at support@sunpal.com. \n type: gateway_timeout, \n http_status_code: 504, \n error_code: gateway_timeout,\n content:"
                + response
            )
        else:
            raise Exception(
                "Sorry, something went wrong when trying to process the request. If this problem persists, contact us at support@sunpal.com. \n type: internal_error, \n http_status_code: 500, \n error_code: internal_error,\n content:"
                + response
            )

    if http_code == 404:
        return {}

    if http_code < 200 or http_code > 299:
        handle_api_resp_error(url, http_code, resp_json)

    return resp_json


def handle_api_resp_error(url, http_code, resp_json):

    # print("resp_json", resp_json)
    if "errors" not in resp_json:
        raise Exception(
            "The api_error_code is not present. Probably an error. \n URL is "
            + url
            + "\nContent is \n "
            + str(resp_json)
        )

    if "operation_failed" == resp_json.get("type"):
        raise OperationFailedError(http_code, resp_json)
    elif "invalid_request" == resp_json.get("type"):
        raise InvalidRequestError(http_code, resp_json)
    else:
        raise APIError(http_code, resp_json)



import os
import sunpal
import unittest

api_key = os.environ.get("API_KEY_SUNPAL")
site = "sunwise"
sunpal.configure(api_key, site)


class UpdateCustomerTestCase(unittest.TestCase):
    def test_send_new_nip(self):
        entry = sunpal.Customer.update(
            "EAEN6506051Y8",
            {
                "first_name": "NOVENTAYTRES",
                "second_name": "PRUEBA",
                "first_last_name": "EXPPAT",
                "second_last_name": "EXPMAT",
            },
        )

        self.assertTrue(entry.customer, True)


if __name__ == "__main__":
    unittest.main()



from sunpal.model import Model
from sunpal import request


class Interactive(Model):
    class Signature(Model):
        fields = ["id", "signature", "created"]

    class DataSheet(Model):
        fields = ["id", "archive", "name", "type"]

    class Documment(Model):
        fields = ["id", "name", "document_reference_id"]

    fields = [
        "id",
        "project_name",
        "has_permalink",
        "has_approbed",
    ]

    @staticmethod
    def create(params=None, env=None, headers=None):
        return request.send(
            "post", request.uri_path("proposals/interactive"), params, env, headers
        )

    @staticmethod
    def retrieve(id, params=None, env=None, headers=None):
        return request.send(
            "get", request.uri_path("proposals/interactive", id), params, env, headers
        )

    @staticmethod
    def update(id, params=None, env=None, headers=None, file=None):
        return request.send(
            "patch",
            request.uri_path("proposals/interactive", id),
            params,
            env,
            headers,
            file,
        )

    @staticmethod
    def delete(id):
        return request.send("delete", request.uri_path("proposals/interactive", id))

    @staticmethod
    def retrieve_signature(id, params=None, env=None, headers=None):
        return request.send(
            "get", request.uri_path("proposals/signature", id), params, env, headers
        )

    @staticmethod
    def retrieve_datasheets(params=None, env=None, headers=None):
        return request.send(
            "get", request.uri_path("proposals/datasheets"), params, env, headers
        )

    @staticmethod
    def add_datasheet(params=None, env=None, headers=None, file=None):
        return request.send(
            "post", request.uri_path("proposals/datasheets"), params, env, headers, file
        )

    @staticmethod
    def delete_datasheet(id, params):
        return request.send(
            "delete", request.uri_path("proposals/datasheets", id), params
        )

    @staticmethod
    def retrieve_documments(params=None, env=None, headers=None):
        return request.send(
            "get", request.uri_path("proposals/documments"), params, env, headers
        )

    @staticmethod
    def add_documment(params=None, env=None, headers=None, file=None):
        return request.send(
            "post", request.uri_path("proposals/documments"), params, env, headers, file
        )

    @staticmethod
    def delete_documment(id, params):
        return request.send(
            "delete", request.uri_path("proposals/documments", id), params
        )

    @staticmethod
    def delete_documment_by_reference(id):
        return request.send(
            "delete", request.uri_path("proposals/documment-reference", id)
        )

    @staticmethod
    def remove_approbal(id):
        return request.send("delete", request.uri_path("proposals/approbed", id))

    @staticmethod
    def revoke_signature(id):
        return request.send("delete", request.uri_path("proposals/signature", id))



from sunpal.model import Model
from sunpal import request


class Customer(Model):
    class StatusItem(Model):
        fields = ["key", "value"]

    class RecordItem(Model):
        fields = ["current", "limit"]

    fields = [
        "id",
        "first_name",
        "last_name",
        "email",
        "status",
    ]

    @staticmethod
    def create(params=None, env=None, headers=None):
        return request.send(
            "post", request.uri_path("accounts/register-customer"), params, env, headers
        )

    @staticmethod
    def send_nip(params=None, env=None, headers=None):
        return request.send(
            "post",
            request.uri_path("accounts/resend/authorization"),
            params,
            env,
            headers,
        )

    @staticmethod
    def list(params=None, env=None, headers=None):
        return request.send_list_request(
            "get", request.uri_path("customers/customer/"), params, env, headers
        )

    @staticmethod
    def retrieve(id, params=None, env=None, headers=None):
        return request.send(
            "get", request.uri_path("accounts/customer", id), params, env, headers
        )

    @staticmethod
    def retrieve_by_reference(id, params=None, env=None, headers=None):
        return request.send(
            "get",
            request.uri_path("accounts/customer-by-reference", id),
            params,
            env,
            headers,
        )

    @staticmethod
    def update(id, params=None, env=None, headers=None):
        return request.send(
            "patch", request.uri_path("accounts/customer", id), params, env, headers
        )

    @staticmethod
    def add_address(id, params, env=None, headers=None):
        params.update({"customer_id": id})
        return request.send("post", "/accounts/address/", params, env, headers)

    @staticmethod
    def update_address(id, params, env=None, headers=None):
        return request.send("patch", f"/accounts/address/{id}/", params, env, headers)

    @staticmethod
    def delete_address(id):
        return request.send("delete", f"/accounts/address/{id}/")



import os
import sunpal
import unittest

api_key = os.environ.get("API_KEY_SUNPAL")
site = "sunwise"
sunpal.configure(api_key, site)


class CustomersTestCase(unittest.TestCase):

    # def test_create_customer(self):
    #     import random

    #     rfc = "".join(random.choice("0123456789ABCDEF") for i in range(13))
    #     item = sunpal.Customer.create(
    #         {
    #             "first_name": "Jason",
    #             "last_name": "Bates",
    #             "second_surname": "Doub",
    #             "rfc": rfc,
    #             "email": "examplesw@yopmail.com",
    #         }
    #     )
    #     self.assertTrue(item, True)

    # def test_create_same_customer(self):

    #     item = sunpal.Customer.create(
    #         {
    #             "first_name": "Jason",
    #             "last_name": "Bates",
    #             "second_surname": "Doub",
    #             "rfc": "GACA910614A36",
    #             "email": "examplesw@yopmail.com",
    #         }
    #     )
    #     self.assertTrue(item, False)

    def test_get_customer(self):
        entry = sunpal.Customer.retrieve(
            id="EAEN6506051Y8",
            params={"reference": "proposal-uuid-sunwise"},
        )
        self.assertTrue(entry.customer, True)

    def test_get_customer_only_by_reference(self):
        entry = sunpal.Customer.retrieve_by_reference("proposal-uuid-sunwise")
        self.assertTrue(entry.customer, True)

    def test_get_dont_customer_exists(self):
        entry = sunpal.Customer.retrieve("ZACE950614A30")
        self.assertTrue(entry, False)


if __name__ == "__main__":
    unittest.main()



import urllib
from sunpal import util, http_request
from sunpal.main import SunPal
from sunpal import compat
import json


def send_list_request(method, url, params=None, env=None, headers=None):
    serialized = {}

    if params is None:
        params = {}

    for k, v in list(params.items()):
        if isinstance(v, list):
            v = json.dumps(v)
        serialized.update({k: v})
    return send(method, url, serialized, env, headers)


def send(method, url, params=None, env=None, headers=None, file=None):
    ser_params = None
    if params and not file:
        ser_params = util.serialize(params)

    if file:
        ser_params = params

    env = env or SunPal.default_env
    response = http_request.request(method, url, env, ser_params, headers, file=file)
    from sunpal.result import Result
    from sunpal.list_result import ListResult

    if "results" in response:
        return ListResult(response["results"], response.get("next_offset", None))
    return Result(response)


def uri_path(*paths):
    url = ""
    for path in paths:
        if path is None or len(str(path).strip()) < 1:
            raise Exception("Id is None or empty")
        if compat.py_major_v >= 3:
            url = url + "/" + urllib.parse.quote(str(path).strip())
        else:
            url = url + "/" + urllib.quote(str(util.get_val(path)))
    return url + "/"



# Always prefer setuptools over distutils
from setuptools import setup, find_packages

# To use a consistent encoding
from codecs import open
from os import path

# The directory containing this file
HERE = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(HERE, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="sunpal",
    version="0.1.9",
    description="Sunpal small library devs",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://sunpal.readthedocs.io/",
    author="sunwise",
    author_email="abner@sunwise.io",
    packages=find_packages(),
    license="MIT",
    classifiers=[
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
    install_requires=["requests"],
)



import os
import sunpal
import unittest

api_key = os.environ.get("API_KEY_SUNPAL")
site = "sunwise"
sunpal.configure(api_key, site)


class RequestTestCase(unittest.TestCase):
    def test_get_customer(self):
        entry = sunpal.Customer.retrieve(
            id="EAEN6506051Y8",
            params={"reference": "proposal-uuid-sunwise"},
        )
        print()
        print(entry.customer.id)
        print(entry.customer.email)
        print(entry.customer.status.key)
        print(entry.customer.records.current)
        self.assertTrue(entry.customer, True)


if __name__ == "__main__":
    unittest.main()



import os
import sunpal
import unittest

api_key = os.environ.get("API_KEY_SUNPAL")
site = "sunwise"
sunpal.configure(api_key, site)


class AddressTestCase(unittest.TestCase):
    def setUp(self):
        self.customer_id = "GACA910614A36"
        item = sunpal.Customer.add_address(
            self.customer_id,
            {
                "street": "Calle 52 #611 x 87 y 89",
                "suburb": "Col. Centro",
                "city": "Mérida",
                "state": "Yuc",
                "favorite": True,
            },
        )
        self.address_id = item.address.id

    def test_update_address(self):
        item = sunpal.Customer.update_address(
            self.address_id,
            {
                "customer_id": self.customer_id,
                "street": "Calle 52 #611 x 87 y 89",
                "suburb": "Col. Centro",
                "city": "Mérida",
                "state": "Yuc",
                "favorite": True,
            },
        )
        self.assertTrue(item, True)

    def test_delete_address(self):
        item = sunpal.Customer.delete_address(self.address_id)
        self.assertTrue(item, True)

    # def tearDown(self):
    #     self.widget.dispose()


# def suite():
#     suite = unittest.TestSuite()
#     suite.addTest(AddressTestCase('test_update_address'))
#     suite.addTest(AddressTestCase('test_delete_address'))
#     return suite

# if __name__ == "__main__":
#     runner = unittest.TextTestRunner(failfast=True)
#     runner.run(suite())

if __name__ == "__main__":
    unittest.main()
